@@ -1,4 +1,4 @@
-/* $Id: read_data.c,v 1.16 2004/03/04 15:29:12 hadess Exp $ */
+/* $Id: read_data.c,v 1.18 2004/06/18 07:38:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -42,9 +42,9 @@ glibtop_read_data_l (glibtop *server)
 #endif
 
 	if (server->socket) {
-		ret = recv (server->socket, (void *)&size, sizeof (size_t), 0);
+		ret = recv (server->socket, &size, sizeof (size_t), 0);
 	} else {
-		ret = read (server->input [0], (void *)&size, sizeof (size_t));
+		ret = read (server->input [0], &size, sizeof (size_t));
 	}
 
 	if (ret < 0)
@@ -54,10 +54,10 @@ glibtop_read_data_l (glibtop *server)
 	fprintf (stderr, "LIBRARY: really reading %d data bytes (ret = %d).\n", size, ret);
 #endif
 
-	if (!size) return NULL;	
+	if (!size) return NULL;
 
 	ptr = g_malloc (size);
-	
+
 	if (server->socket) {
 		ret = recv (server->socket, ptr, size, 0);
 	} else {
