@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.7.4.4 2001/02/27 13:52:56 martin Exp $ */
+/* $Id: netload.c,v 1.21 2004/06/09 18:52:21 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -83,20 +83,21 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
     u_long ifnetaddr, ifnetfound, ifaddraddr;
     struct sockaddr *sa;
     char tname [16];
+    char temp [16];
 
     union {
 	struct ifaddr ifa;
 	struct in_ifaddr in;
     } ifaddr;
-    
+
     glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_NETLOAD), 0);
-	
+
     memset (buf, 0, sizeof (glibtop_netload));
 
     if (kvm_read (server->machine.kd, nlst [0].n_value,
 		  &ifnetaddr, sizeof (ifnetaddr)) != sizeof (ifnetaddr))
 	glibtop_error_io_r (server, "kvm_read (ifnet)");
-    
+
     ifaddraddr = 0;
     while (ifnetaddr || ifaddraddr) {
 	struct sockaddr_in *sin;
@@ -109,13 +110,15 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 			  sizeof (ifnet)) != sizeof (ifnet))
 		    glibtop_error_io_r (server, "kvm_read (ifnetaddr)");
 
-#if defined(__FreeBSD__) || defined(__bsdi__)
+#if (defined(__FreeBSD__) && (__FreeBSD_version < 501113)) || defined(__bsdi__)
 	    if (kvm_read (server->machine.kd, (u_long) ifnet.if_name,
 			  tname, 16) != 16)
 		    glibtop_error_io_r (server, "kvm_read (if_name)");
-#else
-	    strncpy (tname, ifnet.if_xname, 16);
+	    snprintf(temp, (15 - strlen(tname)), "%d", ifnet.if_unit);
+	    strcat(tname, temp);
 	    tname [15] = 0;
+#else
+	    g_strlcpy (tname, ifnet.if_xname, sizeof tname);
 #endif
 
 #if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
@@ -131,48 +134,48 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	    if ((kvm_read (server->machine.kd, ifaddraddr, &ifaddr,
 			   sizeof (ifaddr)) != sizeof (ifaddr)))
 		glibtop_error_io_r (server, "kvm_read (ifaddraddr)");
-	
+
 #define CP(x) ((char *)(x))
 	    cp = (CP(ifaddr.ifa.ifa_addr) - CP(ifaddraddr)) +
 		CP(&ifaddr); sa = (struct sockaddr *)cp;
-	
+
 	    if (!strcmp (interface, tname) && (sa->sa_family == AF_INET)) {
 		sin = (struct sockaddr_in *)sa;
 
 		if (ifnet.if_flags & IFF_UP)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_UP;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_UP);
 		if (ifnet.if_flags & IFF_BROADCAST)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_BROADCAST;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_BROADCAST);
 		if (ifnet.if_flags & IFF_DEBUG)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_DEBUG;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_DEBUG);
 		if (ifnet.if_flags & IFF_LOOPBACK)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LOOPBACK;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_LOOPBACK);
 		if (ifnet.if_flags & IFF_POINTOPOINT)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_POINTOPOINT;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_POINTOPOINT);
 		if (ifnet.if_flags & IFF_RUNNING)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_RUNNING;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_RUNNING);
 		if (ifnet.if_flags & IFF_NOARP)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_NOARP;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_NOARP);
 		if (ifnet.if_flags & IFF_PROMISC)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_PROMISC;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_PROMISC);
 		if (ifnet.if_flags & IFF_ALLMULTI)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_ALLMULTI;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_ALLMULTI);
 		if (ifnet.if_flags & IFF_OACTIVE)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_OACTIVE;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_OACTIVE);
 		if (ifnet.if_flags & IFF_SIMPLEX)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_SIMPLEX;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_SIMPLEX);
 		if (ifnet.if_flags & IFF_LINK0)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK0;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_LINK0);
 		if (ifnet.if_flags & IFF_LINK1)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK1;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_LINK1);
 		if (ifnet.if_flags & IFF_LINK2)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_LINK2;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_LINK2);
 #ifdef __FreeBSD__
 		if (ifnet.if_flags & IFF_ALTPHYS)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_ALTPHYS;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_ALTPHYS);
 #endif
 		if (ifnet.if_flags & IFF_MULTICAST)
-			buf->if_flags |= GLIBTOP_IF_FLAGS_MULTICAST;
+			buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_MULTICAST);
 
 #if !defined(__bsdi__)
 		/* Commenting out to "fix" #13345. */
@@ -207,7 +210,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	    ifaddraddr = (u_long)ifaddr.ifa.ifa_list.tqe_next;
 #endif
 	}
-	
+
 #if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
 	ifnetaddr = (u_long) ifnet.if_link.tqe_next;
 #elif defined(__FreeBSD__) || defined(__bsdi__)
