@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.26 2003/10/20 15:19:50 hadess Exp $ */
+/* $Id: swap.c,v 1.29 2004/06/09 18:52:21 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -147,7 +147,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	struct kvm_swap kvmsw[16];
 # endif
 
-#elif defined(__bsdi__)	
+#elif defined(__bsdi__)
 	struct swapstats swap;
 #elif defined(__NetBSD__)
 	struct swapent *swaplist;
@@ -167,7 +167,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	static int swappgsout = -1;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_swap));
 
 	if (server->sysdeps.swap == 0)
@@ -181,7 +181,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	}
 #else
 	/* This is used to get the `pagein' and `pageout' members. */
-	
+
 	if (kvm_read (server->machine.kd, nlst2[0].n_value,
 		      &vmm, sizeof (vmm)) != sizeof (vmm)) {
 		glibtop_warn_io_r (server, "kvm_read (cnt)");
@@ -267,7 +267,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	/* List of swap devices and sizes. */
 
 	sw_size = nswdev * sizeof (*sw);
-	sw = g_malloc (server, sw_size);
+	sw = g_malloc (sw_size);
 
 	if (kvm_read (server->machine.kd, ptr, sw, sw_size) != (ssize_t)sw_size) {
 		glibtop_warn_io_r (server, "kvm_read (*swdevt)");
@@ -367,8 +367,8 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 	buf->flags = _glibtop_sysdeps_swap;
 
-	buf->used = kvmsw[nswdev].ksw_used;
-	buf->total = kvmsw[nswdev].ksw_total;
+	buf->used = kvmsw[nswdev].ksw_used * getpagesize();
+	buf->total = kvmsw[nswdev].ksw_total * getpagesize();
 
 	buf->free = buf->total - buf->used;
 
@@ -399,7 +399,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		return;
 	}
 
-	swaplist = g_malloc (server, nswap * sizeof (struct swapent));
+	swaplist = g_malloc (nswap * sizeof (struct swapent));
 
 	if (swapctl (SWAP_STATS, swaplist, nswap) != nswap) {
 		glibtop_warn_io_r (server, "swapctl (SWAP_STATS)");
