@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: shm_limits.c,v 1.13 2004/05/25 17:07:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,46 +27,44 @@
 #include <kvm.h>
 #include <sys/shm.h>
 
-static struct nlist nlst[] = { {"shminfo"}, {NULL} };
+static const struct nlist nlst[] = { {"shminfo"}, {NULL} };
 static const unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
-(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG);
 
 /* Init function. */
 
-int
+void
 glibtop_init_shm_limits_p (glibtop *server)
 {
-    kvm_t *kd = server->_priv->machine.kd;
+   	kvm_t *kd = server->machine.kd;
 
-    if(kd && !kvm_nlist(kd, nlst))
-	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
-    else
-	server->sysdeps.shm_limits = 0;
-
-    return 0;
+   	if(kd && !kvm_nlist(kd, nlst))
+		server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+	else
+		server->sysdeps.shm_limits = 0;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-    kvm_t *kd = server->_priv->machine.kd;
-    struct shminfo sinfo;
+   	kvm_t *kd = server->machine.kd;
+	struct shminfo sinfo;
 
-    memset (buf, 0, sizeof (glibtop_shm_limits));
+	memset (buf, 0, sizeof (glibtop_shm_limits));
 
-    if(!(server->sysdeps.shm_limits))
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    if(kvm_read(kd, nlst[0].n_value, (void *)&sinfo,
-		sizeof(struct shminfo)) != sizeof(struct shminfo))
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    buf->shmmax = sinfo.shmmax;
-    buf->shmmin = sinfo.shmmin;
-    buf->shmmni = sinfo.shmmni;
-    buf->shmseg = sinfo.shmseg;
-    buf->flags = _glibtop_sysdeps_shm_limits;
-
-    return 0;
+	if(!(server->sysdeps.shm_limits))
+	   	return;
+	if(kvm_read(kd, nlst[0].n_value, (void *)&sinfo,
+		    sizeof(struct shminfo)) != sizeof(struct shminfo))
+	        return;
+	buf->shmmax = sinfo.shmmax;
+	buf->shmmni = sinfo.shmmni;
+#if GLIBTOP_SOLARIS_RELEASE < 590
+	buf->shmmin = sinfo.shmmin;
+	buf->shmseg = sinfo.shmseg;
+#endif
+	buf->flags = _glibtop_sysdeps_shm_limits;
 }
