@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procsignal.c,v 1.9 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,23 +31,19 @@ static const unsigned long _glibtop_sysdeps_proc_signal = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_signal_p (glibtop *server)
 {
-    server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
-
-    return 0;
+	server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_signal_p (glibtop *server, glibtop_proc_signal *buf,
 			   pid_t pid)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
-	
-    memset (buf, 0, sizeof (glibtop_proc_signal));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
 
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_signal));
 }
